LongRunningRequestResult class

Constructors

LongRunningRequestResult({required Operation operation, List<TranscriptionResult>? results, required Status error})

Properties

error → Status
final
hashCode → int
The hash code for this object.
no setterinherited
operation → Operation
final
results → List<TranscriptionResult>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited