UnsupportedFileExtensionException class

Inheritance

Constructors

UnsupportedFileExtensionException(File? file)
Will be thrown, if a File is passed, which has no json extension.

Properties

file → File?
File that was transferred during initialization.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Message describing the thrown error.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited