SpeechServiceBase class abstract

Annotations
  • @GrpcServiceName.new('google.cloud.speech.v1.Speech')

Constructors

SpeechServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
longRunningRecognize(ServiceCall call, LongRunningRecognizeRequest request) → Future<Operation>
longRunningRecognize_Pre(ServiceCall call, Future<LongRunningRecognizeRequest> request) → Future<Operation>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recognize(ServiceCall call, RecognizeRequest request) → Future<RecognizeResponse>
recognize_Pre(ServiceCall call, Future<RecognizeRequest> request) → Future<RecognizeResponse>
streamingRecognize(ServiceCall call, Stream<StreamingRecognizeRequest> request) → Stream<StreamingRecognizeResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited