BatchRecognizeRequest class

Request message for the google.cloud.speech.v2.Speech.BatchRecognize method.

Inheritance
  • Object
  • GeneratedMessage
  • BatchRecognizeRequest

Constructors

BatchRecognizeRequest({String? recognizer, Iterable<BatchRecognizeFileMetadata>? files, RecognitionConfig? config, FieldMask? configMask, RecognitionOutputConfig? recognitionOutputConfig, BatchRecognizeRequest_ProcessingStrategy? processingStrategy})
factory
BatchRecognizeRequest.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
BatchRecognizeRequest.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

config ↔ RecognitionConfig
Features and audio metadata to use for the Automatic Speech Recognition. This field in combination with the google.cloud.speech.v2.BatchRecognizeRequest.config_mask field can be used to override parts of the google.cloud.speech.v2.Recognizer.default_recognition_config of the Recognizer resource.
getter/setter pair
configMask ↔ FieldMask
The list of fields in google.cloud.speech.v2.BatchRecognizeRequest.config that override the values in the google.cloud.speech.v2.Recognizer.default_recognition_config of the recognizer during this recognition request. If no mask is provided, all given fields in google.cloud.speech.v2.BatchRecognizeRequest.config override the values in the recognizer for this recognition request. If a mask is provided, only the fields listed in the mask override the config in the recognizer for this recognition request. If a wildcard (*) is provided, google.cloud.speech.v2.BatchRecognizeRequest.config completely overrides and replaces the config in the recognizer for this recognition request.
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
files → List<BatchRecognizeFileMetadata>
Audio files with file metadata for ASR. The maximum number of files allowed to be specified is 5.
no setter
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
processingStrategy ↔ BatchRecognizeRequest_ProcessingStrategy
Processing strategy to use for this request.
getter/setter pair
recognitionOutputConfig ↔ RecognitionOutputConfig
Configuration options for where to output the transcripts of each file.
getter/setter pair
recognizer ↔ String
Required. The name of the Recognizer to use during recognition. The expected format is projects/{project}/locations/{location}/recognizers/{recognizer}. The {recognizer} segment may be set to _ to use an empty implicit Recognizer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearConfig() → void
clearConfigMask() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearProcessingStrategy() → void
clearRecognitionOutputConfig() → void
clearRecognizer() → void
clone() → BatchRecognizeRequest
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(BatchRecognizeRequest)) → BatchRecognizeRequest
Apply updates to a copy of this message.
override
createEmptyInstance() → BatchRecognizeRequest
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureConfig() → RecognitionConfig
ensureConfigMask() → FieldMask
ensureRecognitionOutputConfig() → RecognitionOutputConfig
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasConfig() → bool
hasConfigMask() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasProcessingStrategy() → bool
hasRecognitionOutputConfig() → bool
hasRecognizer() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited