OperationMetadata class

Represents the metadata of a long-running operation.

Inheritance
  • Object
  • GeneratedMessage
  • OperationMetadata

Constructors

OperationMetadata({Timestamp? createTime, Timestamp? updateTime, String? resource, String? method, String? kmsKeyName, String? kmsKeyVersionName, BatchRecognizeRequest? batchRecognizeRequest, CreateRecognizerRequest? createRecognizerRequest, UpdateRecognizerRequest? updateRecognizerRequest, DeleteRecognizerRequest? deleteRecognizerRequest, UndeleteRecognizerRequest? undeleteRecognizerRequest, CreateCustomClassRequest? createCustomClassRequest, UpdateCustomClassRequest? updateCustomClassRequest, DeleteCustomClassRequest? deleteCustomClassRequest, UndeleteCustomClassRequest? undeleteCustomClassRequest, CreatePhraseSetRequest? createPhraseSetRequest, UpdatePhraseSetRequest? updatePhraseSetRequest, DeletePhraseSetRequest? deletePhraseSetRequest, UndeletePhraseSetRequest? undeletePhraseSetRequest, @Deprecated('This field is deprecated.') UpdateConfigRequest? updateConfigRequest, int? progressPercent, BatchRecognizeMetadata? batchRecognizeMetadata})
factory
OperationMetadata.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
OperationMetadata.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

batchRecognizeMetadata ↔ BatchRecognizeMetadata
Metadata specific to the BatchRecognize method.
getter/setter pair
batchRecognizeRequest ↔ BatchRecognizeRequest
The BatchRecognizeRequest that spawned the Operation.
getter/setter pair
createCustomClassRequest ↔ CreateCustomClassRequest
The CreateCustomClassRequest that spawned the Operation.
getter/setter pair
createPhraseSetRequest ↔ CreatePhraseSetRequest
The CreatePhraseSetRequest that spawned the Operation.
getter/setter pair
createRecognizerRequest ↔ CreateRecognizerRequest
The CreateRecognizerRequest that spawned the Operation.
getter/setter pair
createTime ↔ Timestamp
The time the operation was created.
getter/setter pair
deleteCustomClassRequest ↔ DeleteCustomClassRequest
The DeleteCustomClassRequest that spawned the Operation.
getter/setter pair
deletePhraseSetRequest ↔ DeletePhraseSetRequest
The DeletePhraseSetRequest that spawned the Operation.
getter/setter pair
deleteRecognizerRequest ↔ DeleteRecognizerRequest
The DeleteRecognizerRequest that spawned the Operation.
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
kmsKeyName ↔ String
The KMS key name with which the content of the Operation is encrypted. The expected format is projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.
getter/setter pair
kmsKeyVersionName ↔ String
The KMS key version name with which content of the Operation is encrypted. The expected format is projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}.
getter/setter pair
method ↔ String
The method that triggered the operation.
getter/setter pair
progressPercent ↔ int
The percent progress of the Operation. Values can range from 0-100. If the value is 100, then the operation is finished.
getter/setter pair
resource ↔ String
The resource path for the target of the operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
undeleteCustomClassRequest ↔ UndeleteCustomClassRequest
The UndeleteCustomClassRequest that spawned the Operation.
getter/setter pair
undeletePhraseSetRequest ↔ UndeletePhraseSetRequest
The UndeletePhraseSetRequest that spawned the Operation.
getter/setter pair
undeleteRecognizerRequest ↔ UndeleteRecognizerRequest
The UndeleteRecognizerRequest that spawned the Operation.
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updateConfigRequest ↔ UpdateConfigRequest
The UpdateConfigRequest that spawned the Operation.
getter/setter pair
updateCustomClassRequest ↔ UpdateCustomClassRequest
The UpdateCustomClassRequest that spawned the Operation.
getter/setter pair
updatePhraseSetRequest ↔ UpdatePhraseSetRequest
The UpdatePhraseSetRequest that spawned the Operation.
getter/setter pair
updateRecognizerRequest ↔ UpdateRecognizerRequest
The UpdateRecognizerRequest that spawned the Operation.
getter/setter pair
updateTime ↔ Timestamp
The time the operation was last updated.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBatchRecognizeMetadata() → void
clearBatchRecognizeRequest() → void
clearCreateCustomClassRequest() → void
clearCreatePhraseSetRequest() → void
clearCreateRecognizerRequest() → void
clearCreateTime() → void
clearDeleteCustomClassRequest() → void
clearDeletePhraseSetRequest() → void
clearDeleteRecognizerRequest() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearKmsKeyName() → void
clearKmsKeyVersionName() → void
clearMetadata() → void
clearMethod() → void
clearProgressPercent() → void
clearRequest() → void
clearResource() → void
clearUndeleteCustomClassRequest() → void
clearUndeletePhraseSetRequest() → void
clearUndeleteRecognizerRequest() → void
clearUpdateConfigRequest() → void
clearUpdateCustomClassRequest() → void
clearUpdatePhraseSetRequest() → void
clearUpdateRecognizerRequest() → void
clearUpdateTime() → void
clone() → OperationMetadata
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(OperationMetadata)) → OperationMetadata
Apply updates to a copy of this message.
override
createEmptyInstance() → OperationMetadata
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureBatchRecognizeMetadata() → BatchRecognizeMetadata
ensureBatchRecognizeRequest() → BatchRecognizeRequest
ensureCreateCustomClassRequest() → CreateCustomClassRequest
ensureCreatePhraseSetRequest() → CreatePhraseSetRequest
ensureCreateRecognizerRequest() → CreateRecognizerRequest
ensureCreateTime() → Timestamp
ensureDeleteCustomClassRequest() → DeleteCustomClassRequest
ensureDeletePhraseSetRequest() → DeletePhraseSetRequest
ensureDeleteRecognizerRequest() → DeleteRecognizerRequest
ensureUndeleteCustomClassRequest() → UndeleteCustomClassRequest
ensureUndeletePhraseSetRequest() → UndeletePhraseSetRequest
ensureUndeleteRecognizerRequest() → UndeleteRecognizerRequest
ensureUpdateConfigRequest() → UpdateConfigRequest
ensureUpdateCustomClassRequest() → UpdateCustomClassRequest
ensureUpdatePhraseSetRequest() → UpdatePhraseSetRequest
ensureUpdateRecognizerRequest() → UpdateRecognizerRequest
ensureUpdateTime() → Timestamp
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBatchRecognizeMetadata() → bool
hasBatchRecognizeRequest() → bool
hasCreateCustomClassRequest() → bool
hasCreatePhraseSetRequest() → bool
hasCreateRecognizerRequest() → bool
hasCreateTime() → bool
hasDeleteCustomClassRequest() → bool
hasDeletePhraseSetRequest() → bool
hasDeleteRecognizerRequest() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasKmsKeyName() → bool
hasKmsKeyVersionName() → bool
hasMethod() → bool
hasProgressPercent() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasResource() → bool
hasUndeleteCustomClassRequest() → bool
hasUndeletePhraseSetRequest() → bool
hasUndeleteRecognizerRequest() → bool
hasUpdateConfigRequest() → bool
hasUpdateCustomClassRequest() → bool
hasUpdatePhraseSetRequest() → bool
hasUpdateRecognizerRequest() → bool
hasUpdateTime() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichMetadata() → OperationMetadata_Metadata
whichRequest() → OperationMetadata_Request
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited