RecognitionConfig class

Provides information to the Recognizer that specifies how to process the recognition request.

Inheritance
  • Object
  • GeneratedMessage
  • RecognitionConfig

Constructors

RecognitionConfig({RecognitionFeatures? features, SpeechAdaptation? adaptation, AutoDetectDecodingConfig? autoDecodingConfig, ExplicitDecodingConfig? explicitDecodingConfig, String? model, Iterable<String>? languageCodes})
factory
RecognitionConfig.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
RecognitionConfig.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

adaptation ↔ SpeechAdaptation
Speech adaptation context that weights recognizer predictions for specific words and phrases.
getter/setter pair
autoDecodingConfig ↔ AutoDetectDecodingConfig
Automatically detect decoding parameters. Preferred for supported formats.
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
explicitDecodingConfig ↔ ExplicitDecodingConfig
Explicitly specified decoding parameters. Required if using headerless PCM audio (linear16, mulaw, alaw).
getter/setter pair
features ↔ RecognitionFeatures
Speech recognition features to enable.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
languageCodes → List<String>
Optional. The language of the supplied audio as a BCP-47 language tag. Language tags are normalized to BCP-47 before they are used eg "en-us" becomes "en-US".
no setter
model ↔ String
Optional. Which model to use for recognition requests. Select the model best suited to your domain to get best results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAdaptation() → void
clearAutoDecodingConfig() → void
clearDecodingConfig() → void
clearExplicitDecodingConfig() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFeatures() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearModel() → void
clone() → RecognitionConfig
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(RecognitionConfig)) → RecognitionConfig
Apply updates to a copy of this message.
override
createEmptyInstance() → RecognitionConfig
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureAdaptation() → SpeechAdaptation
ensureAutoDecodingConfig() → AutoDetectDecodingConfig
ensureExplicitDecodingConfig() → ExplicitDecodingConfig
ensureFeatures() → RecognitionFeatures
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasAdaptation() → bool
hasAutoDecodingConfig() → bool
hasExplicitDecodingConfig() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasFeatures() → bool
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasModel() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichDecodingConfig() → RecognitionConfig_DecodingConfig
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited