uri property
URI that points to a file that contains audio data bytes as specified in
google.cloud.speech.v2.RecognitionConfig. The file
must not be compressed (for example, gzip). Currently, only Google Cloud
Storage URIs are supported, which must be specified in the following
format: gs://bucket_name/object_name (other URI formats return
google.rpc.Code.INVALID_ARGUMENT). For more
information, see Request
URIs.
Implementation
@$pb.TagNumber(6)
$core.String get uri => $_getSZ(3);
Implementation
@$pb.TagNumber(6)
set uri($core.String v) {
$_setString(3, v);
}