OperationsServiceBase class abstract

Annotations
  • @GrpcServiceName.new('google.longrunning.Operations')

Constructors

OperationsServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
cancelOperation(ServiceCall call, CancelOperationRequest request) → Future<Empty>
cancelOperation_Pre(ServiceCall call, Future<CancelOperationRequest> request) → Future<Empty>
deleteOperation(ServiceCall call, DeleteOperationRequest request) → Future<Empty>
deleteOperation_Pre(ServiceCall call, Future<DeleteOperationRequest> request) → Future<Empty>
getOperation(ServiceCall call, GetOperationRequest request) → Future<Operation>
getOperation_Pre(ServiceCall call, Future<GetOperationRequest> request) → Future<Operation>
listOperations(ServiceCall call, ListOperationsRequest request) → Future<ListOperationsResponse>
listOperations_Pre(ServiceCall call, Future<ListOperationsRequest> request) → Future<ListOperationsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitOperation(ServiceCall call, WaitOperationRequest request) → Future<Operation>
waitOperation_Pre(ServiceCall call, Future<WaitOperationRequest> request) → Future<Operation>

Operators

operator ==(Object other) → bool
The equality operator.
inherited